==> drools-planner-core-5.2.1.Final-sources.jar: org/drools/planner/core/localsearch/decider/Decider.java <==
/*
 * Copyright 2010 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.planner.core.localsearch.decider;

import org.drools.planner.core.localsearch.LocalSearchSolverAware;
import org.drools.planner.core.localsearch.LocalSearchSolverLifecycleListener;
import org.drools.planner.core.localsearch.LocalSearchStepScope;
import org.drools.planner.core.localsearch.decider.deciderscorecomparator.DeciderScoreComparatorFactory;
import org.drools.planner.core.localsearch.decider.forager.Forager;

/**
 * A decider decides the next step.
 * @see DefaultDecider
 */
public interface Decider extends LocalSearchSolverAware, LocalSearchSolverLifecycleListener {

    /**
     * Decides the next step
     * @param localSearchStepScope never null
     */
    void decideNextStep(LocalSearchStepScope localSearchStepScope);

    /**
     * @return never null
     */
    DeciderScoreComparatorFactory getDeciderScoreComparator();

    /**
     * @return never null
     */
    Forager getForager();

}

==> drools-planner-core-5.3.4.Final-sources.jar: org/drools/planner/core/localsearch/decider/Decider.java <==
/*
 * Copyright 2010 JBoss Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.drools.planner.core.localsearch.decider;

import org.drools.planner.core.localsearch.LocalSearchSolverAware;
import org.drools.planner.core.localsearch.LocalSearchStepScope;
import org.drools.planner.core.localsearch.decider.deciderscorecomparator.DeciderScoreComparatorFactory;
import org.drools.planner.core.localsearch.decider.forager.Forager;
import org.drools.planner.core.localsearch.event.LocalSearchSolverPhaseLifecycleListener;

/**
 * A decider decides the next step.
 * @see DefaultDecider
 */
public interface Decider extends LocalSearchSolverAware, LocalSearchSolverPhaseLifecycleListener {

    /**
     * Decides the next step
     * @param localSearchStepScope never null
     */
    void decideNextStep(LocalSearchStepScope localSearchStepScope);

    /**
     * @return never null
     */
    DeciderScoreComparatorFactory getDeciderScoreComparator();

    /**
     * @return never null
     */
    Forager getForager();

}
